@@ -88,40 +88,7 @@ def download_nemde(
     files = make_many_nemde_files(start, end, base_directory)
     dataset = []
     for file in files:
-        clean_fi = file.data_directory / "clean.parquet"
-        if clean_fi.exists():
-            print(f" [blue]CACHED[/] {' '.join(clean_fi.parts[-5:])}")
-            data = pd.read_parquet(clean_fi)
-        else:
-            print(f" [blue]NOT CACHED[/] {' '.join(clean_fi.parts[-5:])}")
-
-        data_available = utils.download_zipfile(file)
-
-        if not data_available:
-            print(f" [red]NOT AVAILABLE[/] {' '.join(file.zipfile_path.parts[-5:])}")
-            data = None
-
-        else:
-            print(f" [green]DOWNLOADING[/] {' '.join(file.zipfile_path.parts[-5:])}")
-            utils.download_zipfile(file)
-            utils.unzip(file.zipfile_path)
-            xmls = find_xmls(file.data_directory)
-            data = pd.concat(xmls, axis=0)
-            #  get problems with a value of '5' without the cast to float
-            data["BandNo"] = data["BandNo"].astype(float)
-
-            #  already timezone aware here
-            data["PeriodID"] = pd.to_datetime(data["PeriodID"])
-            assert data["PeriodID"].dt.tz._offset == datetime.timedelta(
-                seconds=3600 * 10
-            )
-            data["PeriodID"] = data["PeriodID"].dt.tz_convert(constants.nem_tz)
-            data = utils.add_interval_column(data, table)
-
-            if not dry_run:
-                print(f" [green]SAVING [/] {clean_fi}")
-                data.to_csv(clean_fi.with_suffix(".csv"))
-                data.to_parquet(clean_fi.with_suffix(".parquet"))
+        data = download_one_nemde(table, file, dry_run)
 
         if data is not None:
             dataset.append(data)
@@ -130,3 +97,42 @@ def download_nemde(
         return pd.concat(dataset, axis=0)
     except ValueError:
         return pd.DataFrame()
+
+
+def download_one_nemde(
+    table: NEMDETable, file: NEMDEFile, dry_run: bool
+) -> typing.Union[pd.DataFrame, None]:
+    clean_fi = file.data_directory / "clean.parquet"
+    if clean_fi.exists():
+        print(f" [blue]CACHED[/] {' '.join(clean_fi.parts[-5:])}")
+        return pd.read_parquet(clean_fi)
+    else:
+        print(f" [blue]NOT CACHED[/] {' '.join(clean_fi.parts[-5:])}")
+
+    data_available = utils.download_zipfile(file)
+
+    if not data_available:
+        print(f" [red]NOT AVAILABLE[/] {' '.join(file.zipfile_path.parts[-5:])}")
+        return None
+
+    else:
+        print(f" [green]DOWNLOADING[/] {' '.join(file.zipfile_path.parts[-5:])}")
+        utils.download_zipfile(file)
+        utils.unzip(file.zipfile_path)
+        xmls = find_xmls(file.data_directory)
+        data = pd.concat(xmls, axis=0)
+
+        #  get problems with a value of '5' without the cast to float
+        data["BandNo"] = data["BandNo"].astype(float)
+
+        #  already timezone aware here
+        data["PeriodID"] = pd.to_datetime(data["PeriodID"])
+        assert data["PeriodID"].dt.tz._offset == datetime.timedelta(seconds=3600 * 10)
+        data["PeriodID"] = data["PeriodID"].dt.tz_convert(constants.nem_tz)
+        data = utils.add_interval_column(data, table)
+
+        if not dry_run:
+            print(f" [green]SAVING [/] {clean_fi}")
+            data.to_csv(clean_fi.with_suffix(".csv"))
+            data.to_parquet(clean_fi.with_suffix(".parquet"))
+        return data
